//
//  ContentView.swift
//  InvasiveApp
//
//  Created by Joe Gregg on 11/8/24.
//

import SwiftUI
import SwiftData

struct ContentView: View {
    @Environment(\.modelContext) private var modelContext
    @StateObject var gateway : Gateway
    @Query var sightings : [Sighting]
    @State var showSigninSheet : Bool = false
    var body: some View {
        NavigationStack {
            VStack {
                NavigationLink("Gallery") {
                    GalleryView(gateway: gateway)
                }
                .padding()
                .background(.green)
                .foregroundColor(.white)
                .cornerRadius(10)
                
                NavigationLink("Record Observation") {
                    RecordingView(gateway: gateway)
                }
                .padding()
                .background(.green)
                .foregroundColor(.white)
                .cornerRadius(10)
                
                Button("Upload Observations") {
                    for s in sightings {
                        Task {
                            if await gateway.uploadSighting(s) {
                                DispatchQueue.main.async {
                                    modelContext.delete(s)
                                    try? modelContext.save()
                                }
                            }
                        }
                    }
                }
                .disabled(gateway.userid == nil || sightings.isEmpty)
                .padding()
                
                Button("Log in") {
                        showSigninSheet = true
                }
                .disabled(gateway.userid != nil)
                .padding()
                .sheet(isPresented: $showSigninSheet, content: {
                    LoginView(gateway: gateway)
                })
            }
        }
    }
}

#Preview {
    ContentView(gateway: Gateway())
}
