//
//  Entities.swift
//  InvasiveApp
//
//  Created by Joe Gregg on 11/8/24.
//

import Foundation
import SwiftData

@Model
final class Species {
    @Attribute(.unique) var id: Int
    var name: String
    var image: String
    
    init(dto: SpeciesDTO) {
        self.id = dto.idspecies
        self.name = dto.name
        self.image = dto.image
    }
}

final class SpeciesDTO : Codable {
    var idspecies : Int
    var name: String
    var image: String
}

@Model
final class Park {
    @Attribute(.unique) var id: Int
    var name: String
    var county: String
    
    init(dto: ParkDTO) {
        self.id = dto.idpark
        self.name = dto.name
        self.county = dto.county
    }
}

final class ParkDTO : Codable {
    var idpark : Int
    var name: String
    var county: String
}

@Model
final class Sighting {
    @Attribute(.unique) var id: String = UUID().uuidString
    var user : Int
    var species : Int
    var park : Int
    var comment : String
    var date : String
    
    init(user: Int, species: Int, park: Int, comment: String, date: String) {
        self.user = user
        self.species = species
        self.park = park
        self.comment = comment
        self.date = date
    }
}

final class SightingDTO : Codable {
    var user : Int
    var species : Int
    var park : Int
    var comment : String
    var date : String
    
    init(sighting : Sighting) {
        self.user = sighting.user
        self.species = sighting.species
        self.park = sighting.park
        self.comment = sighting.comment
        self.date = sighting.date
    }
}

final class UserDTO : Codable {
    var iduser : Int = 0
    var username : String
    var password : String
    var realname : String
    var phone : String
    
    init(username: String, password: String, realname: String, phone: String) {
        self.username = username
        self.password = password
        self.realname = realname
        self.phone = phone
    }
}
