//
//  GalleryView.swift
//  InvasiveApp
//
//  Created by Joe Gregg on 11/8/24.
//

import Foundation
import SwiftUI
import SwiftData

struct GalleryView: View {
    @Environment(\.modelContext) private var modelContext
    @StateObject var gateway : Gateway
    @Query var species : [Species]
    var body: some View {
        List {
            ForEach(species) {s in
                HStack {
                    AsyncImage(url: URL(string: s.image)) { image in
                        image
                            .resizable()
                            .aspectRatio(contentMode: .fill)
                    } placeholder: {
                        Color.gray
                    }
                    .frame(width: 150, height: 100)
                    Text(s.name)
                }
            }
        }.onAppear() {
            if species.isEmpty {
                Task {
                    let dtos = await gateway.fetchSpecies()
                    DispatchQueue.main.async {
                        for dto in dtos {
                            let s = Species(dto: dto)
                            modelContext.insert(s)
                        }
                        try? modelContext.save()
                    }
                }
            }
        }
    }
}


