//
//  Gateway.swift
//  InvasiveApp
//
//  Created by Joe Gregg on 11/8/24.
//

import Foundation
import SwiftUI

class Gateway : ObservableObject {
    @Published var userid : Int?
    
    func fetchSpecies() async -> [SpeciesDTO] {
        let urlStr = "https://cmsc106.net/invasive/species"
        guard let url = URL(string: urlStr) else { return []}
        do {
            let (data, response) = try await URLSession.shared.data(from: url)
            guard (response as! HTTPURLResponse).statusCode == 200 else { return []}
            let result = try JSONDecoder().decode([SpeciesDTO].self, from: data)
            return result
        } catch {
            print("Error in fetchSpecies: \(error)")
        }
        return []
    }
    
    func fetchParks() async -> [ParkDTO] {
        let urlStr = "https://cmsc106.net/invasive/parks"
        guard let url = URL(string: urlStr) else { return []}
        do {
            let (data, response) = try await URLSession.shared.data(from: url)
            guard (response as! HTTPURLResponse).statusCode == 200 else { return [] }
            let result = try JSONDecoder().decode([ParkDTO].self, from: data)
            return result
        } catch {
            print("Error in fetchParks: \(error)")
        }
        return []
    }
    
    func newUser(_ dto : UserDTO) async -> Bool {
        let urlStr = "https://cmsc106.net/invasive/users"
        guard let url = URL(string: urlStr) else { return false }
        var request = URLRequest(url: url)
        request.httpMethod = "POST"
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        do {
            let jsonData = try JSONEncoder().encode(dto)
            let (data, response) = try await URLSession.shared.upload(for: request, from: jsonData)
                
            guard (response as! HTTPURLResponse).statusCode == 200 else { return false }
            let result = try JSONDecoder().decode(UserDTO.self, from: data)
            DispatchQueue.main.async { self.userid = result.iduser }
            return true
        } catch {
            print("Error in newUser: \(error)")
        }
        return false
    }
    
    func login(user: String,password: String) async -> Bool  {
        let urlStr = "https://cmsc106.net/invasive/users?user=\(user)&password=\(password)"
        guard let url = URL(string: urlStr) else { return false}
        do {
            let (data, response) = try await URLSession.shared.data(from: url)
            guard (response as! HTTPURLResponse).statusCode == 200 else { return false }
            let result = try JSONDecoder().decode(UserDTO.self, from: data)
            DispatchQueue.main.async { self.userid = result.iduser }
            return true
        } catch {
            print("Error in login: \(error)")
        }
        return false
    }
    
    func uploadSighting(_ s : Sighting) async -> Bool {
        if let id = userid {
            let urlStr = "https://cmsc106.net/invasive/observations"
            guard let url = URL(string: urlStr) else { return false }
            var request = URLRequest(url: url)
            request.httpMethod = "POST"
            request.setValue("application/json", forHTTPHeaderField: "Content-Type")
            do {
                let dto = SightingDTO(sighting: s)
                dto.user = id
                let jsonData = try JSONEncoder().encode(dto)
                let (_, response) = try await URLSession.shared.upload(for: request, from: jsonData)
                guard (response as! HTTPURLResponse).statusCode == 200 else { return false }
                return true
            } catch {
                print("Error in uploadSighting: \(error)")
            }
        }
        return false
    }
}

