//
//  LoginView.swift
//  InvasiveApp
//
//  Created by Joseph N. Gregg on 11/8/24.
//

import Foundation
import SwiftUI

struct LoginView: View {
    @StateObject var gateway : Gateway
    @Environment(\.dismiss) private var dismiss

    @State var user : String = ""
    @State var password : String = ""
    @State var name : String = ""
    @State var phone : String = ""
    
    var body: some View {
        VStack {
            HStack {
                Text("User:").frame(width:100,height:20,alignment: .trailing)
                TextField("",text:$user).textFieldStyle(.roundedBorder).disableAutocorrection(true)
            }
            HStack {
                Text("Password:").frame(width:100,height:20,alignment: .trailing)
                SecureField("",text:$password).textFieldStyle(.roundedBorder)
            }
            HStack {
                Text("Name:").frame(width:100,height:20,alignment: .trailing)
                TextField("",text:$name).textFieldStyle(.roundedBorder).disableAutocorrection(true)
            }
            HStack {
                Text("Phone:").frame(width:100,height:20,alignment: .trailing)
                TextField("",text:$phone).textFieldStyle(.roundedBorder).disableAutocorrection(true)
            }
            HStack {
                Button("New User"){
                    let dto = UserDTO(username: user, password: password, realname: name, phone: phone)
                    Task {
                        if await gateway.newUser(dto) {
                            dismiss()
                        }
                    }
                }.buttonStyle(.borderedProminent).padding()
                Spacer()
                Button("Log In"){
                    Task {
                        if await gateway.login(user: user, password: password) {
                            dismiss()
                        }
                    }
                }.buttonStyle(.borderedProminent).padding()
            }
        }
        
    }
}
