//
//  RecordingView.swift
//  InvasiveApp
//
//  Created by Joseph N. Gregg on 11/8/24.
//

import Foundation
import SwiftUI
import SwiftData

struct RecordingView: View {
    @Environment(\.modelContext) private var modelContext
    @StateObject var gateway : Gateway
    @Query var parks : [Park]
    @State var selectedPark : Park?
    @Query var species : [Species]
    @State var selectedSpecies : Species?
    @State var comment : String = ""
    @State var date : String = ""
    var body: some View {
        VStack {
            Picker("Park",selection:$selectedPark) {
                ForEach(parks) { park in Text(park.name).tag(park.self as Park?) }
            }
            Picker("Species",selection: $selectedSpecies) {
                ForEach(species) { species in Text(species.name).tag(species.self as Species?)}
            }
            TextField("Enter a comment",text:$comment)
            TextField("Enter a date",text:$date)
            Button("Save Observation") {
                if let sp = selectedPark {
                    if let ss = selectedSpecies {
                        let obs = Sighting(user: gateway.userid ?? 0,
                                           species: ss.id,
                                           park: sp.id,
                                           comment: comment,
                                           date: date)
                        modelContext.insert(obs)
                        try? modelContext.save()
                    }
                }
            }
        }.padding()
        .onAppear() {
            if species.isEmpty {
                Task {
                    let sdtos = await gateway.fetchSpecies()
                    DispatchQueue.main.async {
                        for dto in sdtos {
                            let s = Species(dto: dto)
                            modelContext.insert(s)
                        }
                        try? modelContext.save()
                    }
                }
            }
            if parks.isEmpty {
                Task {
                    let pdtos = await gateway.fetchParks()
                    DispatchQueue.main.async {
                        for dto in pdtos {
                            let p = Park(dto: dto)
                            modelContext.insert(p)
                        }
                        try? modelContext.save()
                    }
                }
            }
        }
    }
}

